@@ -1,3 +1,5 @@
+from loguru import logger
+
 from brats.core.inpainting_algorithms import Inpainter
 from brats.core.missing_mri_algorithms import MissingMRI
 from brats.core.segmentation_algorithms import (
@@ -9,3 +11,5 @@ from brats.core.segmentation_algorithms import (
     MetastasesSegmenter,
     PediatricSegmenter,
 )
+
+logger.remove()
